#Data from: http://earthquake.usgs.gov/earthquakes/eqarchives/epic/

library(ggmap)
library(ggplot2)
library(scales)

quake.data <- read.csv(file="data/quakes2.csv")
str(quake.data)
head(quake.data)

quake.map <- get_map(location = c(-117.516, 31.96, -116.004, 33.76), maptype="toner", source="stamen")

ggmap(quake.map)

ggmap(quake.map) + geom_point(data=quake.data, aes(x=Longitude, y=Latitude, size=Magnitude, color=Depth))

ggmap(quake.map) + geom_point(data=quake.data, aes(x=Longitude, y=Latitude, size=Magnitude, color=Depth)) + scale_color_gradient(low="yellow", high="red")

ggmap(quake.map) + geom_point(data=quake.data, aes(x=Longitude, y=Latitude, size=Magnitude, color=Depth)) + scale_color_gradient(low="yellow", high="red", na.value="darkslategray3")

ggmap(quake.map) + geom_point(data=quake.data, aes(x=Longitude, y=Latitude, size=Magnitude, color=Depth)) + scale_color_gradient(low="yellow", high="red", na.value="darkslategray3") + scale_size_area()

ggmap(quake.map) + geom_point(data=quake.data, aes(x=Longitude, y=Latitude, size=Magnitude, color=Depth)) + scale_color_gradient(low="yellow", high="red", na.value="darkslategray3") + scale_size_area() + xlab("longitude") + ylab("latitude") + ggtitle("Earthquakes from 2013-06-07 through 2013-06-14")

ggmap(quake.map) + geom_point(data=quake.data, aes(x=Longitude, y=Latitude, size=Magnitude, color=Depth)) + scale_color_gradient(low="yellow", high="red", na.value="darkslategray3") + scale_size_area() + xlab("longitude") + ylab("latitude") + ggtitle("Earthquakes from 2013-06-07 through 2013-06-14") + theme(plot.title = element_text(face="bold"))

ggmap(quake.map, extent="panel") + geom_point(data=quake.data, aes(x=Longitude, y=Latitude, size=Magnitude, color=Depth)) + scale_color_gradient(low="yellow", high="red", na.value="darkslategray3") + scale_size_area() + xlab("") + ylab("") + ggtitle("Earthquakes from 2013-06-07 through 2013-06-14") + theme(plot.title = element_text(face="bold", size=rel(0.75), vjust=1), axis.ticks=element_blank(), axis.text=element_blank())

ggmap(quake.map, extent="panel") + geom_point(data=quake.data, aes(x=Longitude, y=Latitude, size=Magnitude, color=Depth)) + scale_color_gradient(low="yellow", high="red", na.value="darkslategray3") + scale_size_area() + geom_text(data=droplevels(subset(quake.data, Magnitude > 2)), aes(x=Longitude, y=Latitude, label=MagType), hjust=1, vjust=1) + xlab("") + ylab("") + ggtitle("Earthquakes from 2013-06-07 through 2013-06-14") + theme(plot.title = element_text(face="bold", size=rel(0.75), vjust=1), axis.ticks=element_blank(), axis.text=element_blank())

ggmap(quake.map, extent="panel") + geom_point(data=quake.data, aes(x=Longitude, y=Latitude, size=Magnitude, color=Depth)) + scale_color_gradient(low="yellow", high="red", na.value="darkslategray3") + scale_size_area() + geom_text(data=droplevels(subset(quake.data, Magnitude > 2 & Latitude > -1.73*Longitude - 170)), aes(x=Longitude, y=Latitude, label=MagType), hjust=1, vjust=1) + geom_text(data=droplevels(subset(quake.data, Magnitude > 2 & Latitude < -1.73*Longitude - 170)), aes(x=Longitude, y=Latitude, label=MagType), color="white", hjust=1, vjust=1) + xlab("") + ylab("") + ggtitle("Earthquakes from 2013-06-07 through 2013-06-14") + theme(plot.title = element_text(face="bold", size=rel(0.75), vjust=1), axis.ticks=element_blank(), axis.text=element_blank())
